@@ -96,7 +96,7 @@ void FakeServer::addScenario(const QList<QByteArray> &scenario)
 void FakeServer::addScenarioFromFile(const QString &fileName)
 {
     QFile file(fileName);
-    file.open(QFile::ReadOnly);
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
 
     QList<QByteArray> scenario;
 
@@ -124,7 +124,7 @@ bool FakeServer::isAllScenarioDone() const
 {
     QMutexLocker locker(&m_mutex);
 
-    for (const QList<QByteArray> &scenario : qAsConst(m_scenarios)) {
+    for (const QList<QByteArray> &scenario : std::as_const(m_scenarios)) {
         if (!scenario.isEmpty()) {
             return false;
         }
